@@ -2,7 +2,7 @@ import os
 import json
 import pkg_resources
 
-BASE_URL_CSS = "https://static.snoweb.fr/snowebsvg/dist/css/"
+BASE_URL_CSS = "https://static.snoweb.io/snowebsvg/dist/css/"
 
 try:
     #  Production part
@@ -19,3 +19,9 @@ SVG_DEFAULT_WIDTH = 100
 SVG_DEFAULT_HEIGHT = 100
 SVG_DEFAULT_VARIANT = None
 SVG_DEFAULT_KEY = 'decorator-rect-basic'
+
+try:
+    import wagtail
+    WAGTAIL_INSTALL = True
+except ImportError:
+    WAGTAIL_INSTALL = False
